@@ -115,7 +115,7 @@ func (d *Deployment) Restart(ctx context.Context, path string) error {
 
 // TailLogs tail logs for all pods represented by this Deployment.
 func (d *Deployment) TailLogs(ctx context.Context, opts *LogOptions) ([]LogChan, error) {
-	dp, err := d.Load(d.Factory, opts.Path)
+	dp, err := d.GetInstance(d.Factory, opts.Path)
 	if err != nil {
 		return nil, err
 	}
@@ -128,7 +128,7 @@ func (d *Deployment) TailLogs(ctx context.Context, opts *LogOptions) ([]LogChan,
 
 // Pod returns a pod victim by name.
 func (d *Deployment) Pod(fqn string) (string, error) {
-	dp, err := d.Load(d.Factory, fqn)
+	dp, err := d.GetInstance(d.Factory, fqn)
 	if err != nil {
 		return "", err
 	}
@@ -136,8 +136,8 @@ func (d *Deployment) Pod(fqn string) (string, error) {
 	return podFromSelector(d.Factory, dp.Namespace, dp.Spec.Selector.MatchLabels)
 }
 
-// Load returns a deployment instance.
-func (*Deployment) Load(f Factory, fqn string) (*appsv1.Deployment, error) {
+// GetInstance fetch a matching deployment.
+func (*Deployment) GetInstance(f Factory, fqn string) (*appsv1.Deployment, error) {
 	o, err := f.Get("apps/v1/deployments", fqn, true, labels.Everything())
 	if err != nil {
 		return nil, err
@@ -240,7 +240,7 @@ func (d *Deployment) Scan(ctx context.Context, gvr, fqn string, wait bool) (Refs
 
 // GetPodSpec returns a pod spec given a resource.
 func (d *Deployment) GetPodSpec(path string) (*v1.PodSpec, error) {
-	dp, err := d.Load(d.Factory, path)
+	dp, err := d.GetInstance(d.Factory, path)
 	if err != nil {
 		return nil, err
 	}
