@@ -67,15 +67,19 @@ func (s *StatefulSet) Scale(ctx context.Context, path string, replicas int32) er
 
 // Restart a StatefulSet rollout.
 func (s *StatefulSet) Restart(ctx context.Context, path string) error {
-	o, err := s.GetFactory().Get("apps/v1/statefulsets", path, true, labels.Everything())
+	sts, err := s.GetInstance(s.Factory, path)
 	if err != nil {
 		return err
 	}
-	var sts appsv1.StatefulSet
-	err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &sts)
+
+	ns, _ := client.Namespaced(path)
+	pp, err := podsFromSelector(s.Factory, ns, sts.Spec.Selector.MatchLabels)
 	if err != nil {
 		return err
 	}
+	for _, p := range pp {
+		s.Forwarders().Kill(client.FQN(p.Namespace, p.Name))
+	}
 
 	auth, err := s.Client().CanI(sts.Namespace, "apps/v1/statefulsets", []string{client.PatchVerb})
 	if err != nil {
@@ -90,12 +94,12 @@ func (s *StatefulSet) Restart(ctx context.Context, path string) error {
 		return err
 	}
 
-	before, err := runtime.Encode(scheme.Codecs.LegacyCodec(appsv1.SchemeGroupVersion), &sts)
+	before, err := runtime.Encode(scheme.Codecs.LegacyCodec(appsv1.SchemeGroupVersion), sts)
 	if err != nil {
 		return err
 	}
 
-	after, err := polymorphichelpers.ObjectRestarterFn(&sts)
+	after, err := polymorphichelpers.ObjectRestarterFn(sts)
 	if err != nil {
 		return err
 	}
@@ -115,8 +119,8 @@ func (s *StatefulSet) Restart(ctx context.Context, path string) error {
 
 }
 
-// Load returns a statefulset instance.
-func (*StatefulSet) Load(f Factory, fqn string) (*appsv1.StatefulSet, error) {
+// GetInstance returns a statefulset instance.
+func (*StatefulSet) GetInstance(f Factory, fqn string) (*appsv1.StatefulSet, error) {
 	o, err := f.Get("apps/v1/statefulsets", fqn, true, labels.Everything())
 	if err != nil {
 		return nil, err
@@ -301,3 +305,26 @@ func (s *StatefulSet) SetImages(ctx context.Context, path string, imageSpecs Ima
 	)
 	return err
 }
+
+func podsFromSelector(f Factory, ns string, sel map[string]string) ([]*v1.Pod, error) {
+	oo, err := f.List("v1/pods", ns, true, labels.Set(sel).AsSelector())
+	if err != nil {
+		return nil, err
+	}
+
+	if len(oo) == 0 {
+		return nil, fmt.Errorf("no matching pods for %v", sel)
+	}
+
+	pp := make([]*v1.Pod, 0, len(oo))
+	for _, o := range oo {
+		pod := new(v1.Pod)
+		err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, pod)
+		if err != nil {
+			return nil, err
+		}
+		pp = append(pp, pod)
+	}
+
+	return pp, nil
+}
