@@ -57,7 +57,7 @@ func (d Deployment) Render(o interface{}, ns string, r *Row) error {
 		strconv.Itoa(int(dp.Status.AvailableReplicas)),
 		mapToStr(dp.Labels),
 		asStatus(d.diagnose(dp.Status.Replicas, dp.Status.AvailableReplicas)),
-		toAge(dp.ObjectMeta.CreationTimestamp),
+		toAge(dp.GetCreationTimestamp()),
 	}
 
 	return nil
