@@ -55,7 +55,7 @@ func (d DaemonSet) Render(o interface{}, ns string, r *Row) error {
 		strconv.Itoa(int(ds.Status.NumberAvailable)),
 		mapToStr(ds.Labels),
 		asStatus(d.diagnose(ds.Status.DesiredNumberScheduled, ds.Status.NumberReady)),
-		toAge(ds.ObjectMeta.CreationTimestamp),
+		toAge(ds.GetCreationTimestamp()),
 	}
 
 	return nil
