@@ -17,6 +17,7 @@ type HeaderColumn struct {
 	Wide      bool
 	MX        bool
 	Time      bool
+	Capacity  bool
 }
 
 // Clone copies a header.
@@ -163,6 +164,15 @@ func (h Header) IsTimeCol(col int) bool {
 	return h[col].Time
 }
 
+// IsCapacityCol checks if given column index represents a capacity.
+func (h Header) IsCapacityCol(col int) bool {
+	if col < 0 || col >= len(h) {
+		return false
+	}
+
+	return h[col].Capacity
+}
+
 // ValidColIndex returns the valid col index or -1 if none.
 func (h Header) ValidColIndex() int {
 	return h.IndexOf("VALID", true)
