@@ -304,7 +304,7 @@ func TestRowsSortText(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			u.rows.Sort(u.col, u.asc, u.num, false)
+			u.rows.Sort(u.col, u.asc, u.num, false, false)
 			assert.Equal(t, u.e, u.rows)
 		})
 	}
@@ -369,7 +369,7 @@ func TestRowsSortDuration(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			u.rows.Sort(u.col, u.asc, false, true)
+			u.rows.Sort(u.col, u.asc, false, true, false)
 			assert.Equal(t, u.e, u.rows)
 		})
 	}
@@ -411,7 +411,49 @@ func TestRowsSortMetrics(t *testing.T) {
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			u.rows.Sort(u.col, u.asc, true, false)
+			u.rows.Sort(u.col, u.asc, true, false, false)
+			assert.Equal(t, u.e, u.rows)
+		})
+	}
+}
+
+func TestRowsSortCapacity(t *testing.T) {
+	uu := map[string]struct {
+		rows render.Rows
+		col  int
+		asc  bool
+		e    render.Rows
+	}{
+		"capacityAsc": {
+			rows: render.Rows{
+				{Fields: []string{"10Gi", "duh"}},
+				{Fields: []string{"10G", "blee"}},
+			},
+			col: 0,
+			asc: true,
+			e: render.Rows{
+				{Fields: []string{"10G", "blee"}},
+				{Fields: []string{"10Gi", "duh"}},
+			},
+		},
+		"capacityDesc": {
+			rows: render.Rows{
+				{Fields: []string{"10000m", "1000Mi"}},
+				{Fields: []string{"1m", "50Mi"}},
+			},
+			col: 1,
+			asc: false,
+			e: render.Rows{
+				{Fields: []string{"10000m", "1000Mi"}},
+				{Fields: []string{"1m", "50Mi"}},
+			},
+		},
+	}
+
+	for k := range uu {
+		u := uu[k]
+		t.Run(k, func(t *testing.T) {
+			u.rows.Sort(u.col, u.asc, false, false, true)
 			assert.Equal(t, u.e, u.rows)
 		})
 	}
@@ -419,14 +461,17 @@ func TestRowsSortMetrics(t *testing.T) {
 
 func TestLess(t *testing.T) {
 	uu := map[string]struct {
-		isNumber, isDuration bool
-		id1, id2             string
-		v1, v2               string
-		e                    bool
+		isNumber   bool
+		isDuration bool
+		isCapacity bool
+		id1, id2   string
+		v1, v2     string
+		e          bool
 	}{
 		"years": {
 			isNumber:   false,
 			isDuration: true,
+			isCapacity: false,
 			id1:        "id1",
 			id2:        "id2",
 			v1:         "2y263d",
@@ -435,17 +480,38 @@ func TestLess(t *testing.T) {
 		"hours": {
 			isNumber:   false,
 			isDuration: true,
+			isCapacity: false,
 			id1:        "id1",
 			id2:        "id2",
 			v1:         "2y263d",
 			v2:         "19h",
 		},
+		"capacity1": {
+			isNumber:   false,
+			isDuration: false,
+			isCapacity: true,
+			id1:        "id1",
+			id2:        "id2",
+			v1:         "1Gi",
+			v2:         "1G",
+			e:          false,
+		},
+		"capacity2": {
+			isNumber:   false,
+			isDuration: false,
+			isCapacity: true,
+			id1:        "id1",
+			id2:        "id2",
+			v1:         "1Gi",
+			v2:         "1Ti",
+			e:          true,
+		},
 	}
 
 	for k := range uu {
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
-			assert.Equal(t, u.e, render.Less(u.isNumber, u.isDuration, u.id1, u.id2, u.v1, u.v2))
+			assert.Equal(t, u.e, render.Less(u.isNumber, u.isDuration, u.isCapacity, u.id1, u.id2, u.v1, u.v2))
 		})
 	}
 }
