@@ -4,7 +4,7 @@ import (
 	"sort"
 
 	"github.com/derailed/k9s/internal/model"
-	"github.com/gdamore/tcell/v2"
+	"github.com/derailed/tcell/v2"
 	"github.com/rs/zerolog/log"
 )
 
