@@ -148,7 +148,7 @@ func (m *Menu) buildMenuTable(hh model.MenuHints, table []model.MenuHints, colCo
 func (m *Menu) layout(table []model.MenuHints, mm []int, out [][]string) {
 	for r := range table {
 		for c := range table[r] {
-			out[r][c] = keyConv(m.formatMenu(table[r][c], mm[c]))
+			out[r][c] = m.formatMenu(table[r][c], mm[c])
 		}
 	}
 }
@@ -169,10 +169,9 @@ func (m *Menu) formatMenu(h model.MenuHint, size int) string {
 // Helpers...
 
 func keyConv(s string) string {
-	if !strings.Contains(s, "alt") {
+	if s == "" || !strings.Contains(s, "alt") {
 		return s
 	}
-
 	if runtime.GOOS != "darwin" {
 		return s
 	}
@@ -185,8 +184,8 @@ func Truncate(str string, width int) string {
 	return runewidth.Truncate(str, width, string(tview.SemigraphicsHorizontalEllipsis))
 }
 
-func toMnemonic(s string) string {
-	if len(s) == 0 {
+func ToMnemonic(s string) string {
+	if s == "" {
 		return s
 	}
 
@@ -197,6 +196,7 @@ func formatNSMenu(i int, name string, styles config.Frame) string {
 	fmat := strings.Replace(menuIndexFmt, "[key", "["+styles.Menu.NumKeyColor.String(), 1)
 	fmat = strings.Replace(fmat, ":bg:", ":"+styles.Title.BgColor.String()+":", -1)
 	fmat = strings.Replace(fmat, "[fg", "["+styles.Menu.FgColor.String(), 1)
+
 	return fmt.Sprintf(fmat, i, name)
 }
 
@@ -205,5 +205,6 @@ func formatPlainMenu(h model.MenuHint, size int, styles config.Frame) string {
 	fmat := strings.Replace(menuFmt, "[key", "["+styles.Menu.KeyColor.String(), 1)
 	fmat = strings.Replace(fmat, "[fg", "["+styles.Menu.FgColor.String(), 1)
 	fmat = strings.Replace(fmat, ":bg:", ":"+styles.Title.BgColor.String()+":", -1)
-	return fmt.Sprintf(fmat, toMnemonic(h.Mnemonic), h.Description)
+
+	return fmt.Sprintf(fmat, ToMnemonic(h.Mnemonic), h.Description)
 }
