@@ -31,11 +31,12 @@ type (
 
 // Table represents tabular data.
 type Table struct {
-	gvr     client.GVR
-	sortCol SortColumn
-	header  render.Header
-	Path    string
-	Extras  string
+	gvr        client.GVR
+	sortCol    SortColumn
+	manualSort bool
+	header     render.Header
+	Path       string
+	Extras     string
 	*SelectTable
 	actions     KeyActions
 	cmdBuff     *model.FishBuff
@@ -85,7 +86,7 @@ func (t *Table) GVR() client.GVR { return t.gvr }
 
 // ViewSettingsChanged notifies listener the view configuration changed.
 func (t *Table) ViewSettingsChanged(settings config.ViewSetting) {
-	t.viewSetting = &settings
+	t.viewSetting, t.manualSort = &settings, false
 	t.Refresh()
 }
 
@@ -202,9 +203,11 @@ func (t *Table) doUpdate(data *render.TableData) {
 		cols = t.viewSetting.Columns
 	}
 	custData := data.Customize(cols, t.wide)
-	if t.viewSetting != nil && t.viewSetting.SortColumn != "" {
+	// The sortColumn settings in the configuration file are only used
+	// if the sortCol has not been modified manually
+	if t.viewSetting != nil && t.viewSetting.SortColumn != "" && !t.manualSort {
 		tokens := strings.Split(t.viewSetting.SortColumn, ":")
-		if custData.Header.IndexOf(tokens[0], false) >= 0 && custData.Header.IndexOf(t.sortCol.name, false) < 0 {
+		if custData.Header.IndexOf(tokens[0], false) >= 0 && !t.manualSort {
 			t.sortCol.name, t.sortCol.asc = tokens[0], true
 			if len(tokens) == 2 && tokens[1] == "desc" {
 				t.sortCol.asc = false
@@ -247,6 +250,7 @@ func (t *Table) doUpdate(data *render.TableData) {
 		colIndex,
 		custData.Header.IsTimeCol(colIndex),
 		custData.Header.IsMetricsCol(colIndex),
+		custData.Header.IsCapacityCol(colIndex),
 		t.sortCol.asc,
 	)
 
@@ -310,11 +314,13 @@ func (t *Table) buildRow(r int, re, ore render.RowEvent, h render.Header, pads M
 // SortColCmd designates a sorted column.
 func (t *Table) SortColCmd(name string, asc bool) func(evt *tcell.EventKey) *tcell.EventKey {
 	return func(evt *tcell.EventKey) *tcell.EventKey {
+		t.manualSort = true
 		t.sortCol.asc = !t.sortCol.asc
 		if t.sortCol.name != name {
 			t.sortCol.asc = asc
 		}
 		t.sortCol.name = name
+		t.manualSort = true
 		t.Refresh()
 		return nil
 	}
