@@ -10,7 +10,7 @@ import (
 
 func TestAppNew(t *testing.T) {
 	a := view.NewApp(config.NewConfig(ks{}))
-	a.Init("blee", 10)
+	_ = a.Init("blee", 10)
 
 	assert.Equal(t, 11, len(a.GetActions()))
 }
