@@ -3,7 +3,7 @@ package view
 import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/ui"
-	"github.com/gdamore/tcell/v2"
+	"github.com/derailed/tcell/v2"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/labels"
@@ -67,7 +67,7 @@ func (s *Secret) decodeCmd(evt *tcell.EventKey) *tcell.EventKey {
 	}
 
 	details := NewDetails(s.App(), "Secret Decoder", path, true).Update(string(raw))
-	if err := s.App().inject(details); err != nil {
+	if err := s.App().inject(details, false); err != nil {
 		s.App().Flash().Err(err)
 	}
 
