@@ -38,7 +38,7 @@ func (s *StatefulSet) logOptions(prev bool) (*dao.LogOptions, error) {
 		return nil, errors.New("you must provide a selection")
 	}
 
-	sts, err := s.sts(path)
+	sts, err := s.getInstance(path)
 	if err != nil {
 		return nil, err
 	}
@@ -82,16 +82,16 @@ func (s *StatefulSet) bindKeys(aa ui.KeyActions) {
 }
 
 func (s *StatefulSet) showPods(app *App, _ ui.Tabular, _, path string) {
-	sts, err := s.sts(path)
+	i, err := s.getInstance(path)
 	if err != nil {
 		app.Flash().Err(err)
 		return
 	}
 
-	showPodsFromSelector(app, path, sts.Spec.Selector)
+	showPodsFromSelector(app, path, i.Spec.Selector)
 }
 
-func (s *StatefulSet) sts(path string) (*appsv1.StatefulSet, error) {
+func (s *StatefulSet) getInstance(path string) (*appsv1.StatefulSet, error) {
 	var sts dao.StatefulSet
-	return sts.Load(s.App().factory, path)
+	return sts.GetInstance(s.App().factory, path)
 }
