@@ -9,21 +9,21 @@ import (
 	"time"
 
 	"github.com/derailed/k9s/internal/client"
-	"github.com/derailed/k9s/internal/dao"
+	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/rs/zerolog/log"
 )
 
-func computeFilename(screenDumpDir, cluster, ns, title, path string) (string, error) {
+func computeFilename(screenDumpDir, context, ns, title, path string) (string, error) {
 	now := time.Now().UnixNano()
 
-	dir := filepath.Join(screenDumpDir, dao.SanitizeFilename(cluster))
+	dir := filepath.Join(screenDumpDir, context)
 	if err := ensureDir(dir); err != nil {
 		return "", err
 	}
 
-	name := title + "-" + dao.SanitizeFilename(path)
+	name := title + "-" + config.SanitizeFilename(path)
 	if path == "" {
 		name = title
 	}
@@ -38,13 +38,13 @@ func computeFilename(screenDumpDir, cluster, ns, title, path string) (string, er
 	return strings.ToLower(filepath.Join(dir, fName)), nil
 }
 
-func saveTable(screenDumpDir, cluster, title, path string, data *render.TableData) (string, error) {
+func saveTable(screenDumpDir, context, title, path string, data *render.TableData) (string, error) {
 	ns := data.Namespace
 	if client.IsClusterWide(ns) {
 		ns = client.NamespaceAll
 	}
 
-	fPath, err := computeFilename(screenDumpDir, cluster, ns, title, path)
+	fPath, err := computeFilename(screenDumpDir, context, ns, title, path)
 	if err != nil {
 		return "", err
 	}
