@@ -22,7 +22,7 @@ type Forwarder interface {
 	// Container returns a container name.
 	Container() string
 
-	// Ports returns the port mapping.
+	// Port returns the port mapping.
 	Port() string
 
 	// FQN returns the full port-forward name.
@@ -49,9 +49,9 @@ func NewForwarders() Forwarders {
 	return make(map[string]Forwarder)
 }
 
-// BOZO!! Review!!!
 // IsPodForwarded checks if pod has a forward.
 func (ff Forwarders) IsPodForwarded(fqn string) bool {
+	fqn += "|"
 	for k := range ff {
 		if strings.HasPrefix(k, fqn) {
 			return true
@@ -63,9 +63,9 @@ func (ff Forwarders) IsPodForwarded(fqn string) bool {
 
 // IsContainerForwarded checks if pod has a forward.
 func (ff Forwarders) IsContainerForwarded(fqn, co string) bool {
-	prefix := fqn + "|" + co
+	fqn += "|" + co
 	for k := range ff {
-		if strings.HasPrefix(k, prefix) {
+		if strings.HasPrefix(k, fqn) {
 			return true
 		}
 	}
@@ -85,8 +85,14 @@ func (ff Forwarders) DeleteAll() {
 // Kill stops and delete a port-forwards associated with pod.
 func (ff Forwarders) Kill(path string) int {
 	var stats int
+
+	// The way port forwards are stored is `pod_fqn|container|local_port:container_port`
+	// The '|' is added to make sure we do not delete port forwards from other pods that have the same prefix
+	// Without the `|` port forwards for pods, default/web-0 and default/web-0-bla would be both deleted
+	// even if we want only port forwards for default/web-0 to be deleted
+	prefix := path + "|"
 	for k, f := range ff {
-		if strings.HasPrefix(k, path) {
+		if k == path || strings.HasPrefix(k, prefix) {
 			stats++
 			log.Debug().Msgf("Stop + Delete port-forward %s", k)
 			f.Stop()
@@ -101,6 +107,6 @@ func (ff Forwarders) Kill(path string) int {
 func (ff Forwarders) Dump() {
 	log.Debug().Msgf("----------- PORT-FORWARDS --------------")
 	for k, f := range ff {
-		log.Debug().Msgf("  %s -- %#v", k, f)
+		log.Debug().Msgf("  %s -- %s", k, f)
 	}
 }
